\name{decompTumor2Sig-package}
\alias{decompTumor2Sig-package}
\alias{decompTumor2Sig}
\docType{package}
\title{
decompTumor2Sig
}
\description{
  The decompTumor2Sig package uses quadratic programming to decompose
  the mutation catalog from an individual tumor sample (or multiple
  individual tumor samples) into a set of given mutational signatures
  (either the Alexandrov model or the Shiraishi model), computing
  weights that reflect the contributions of the signatures to the
  mutation load of the tumor.

  The package additionally provides helper functions to extract genomes
  (mutation catalogs) and signatures from objects provided by
  pmsignature or to read them from files.
}
\details{
\tabular{ll}{
Package: \tab decompTumor2Sig\cr
Type: \tab Package\cr
Version: \tab 1.2.0\cr
Date: \tab 2018-03-04\cr
License: \tab GPL (>=2)\cr
}
The package provides the following functions:
\tabular{ll}{
  decomposeTumorGenomes():\tab determines the weights/contributions of
  a set of SIGNATURES to each of a set of individual tumor GENOMES.\cr
  loadGenomesFromVCF():\tab loads a genome or set of genomes from a
  Variant Call Format (VCF) file.\cr
  loadGenomesFromMPF():\tab loads a genome or set of genomes from a
  Mutation Position Format (MPF) file.\cr
  getGenomesFromMutationFeatureData():\tab extracts the GENOMES from a
  MutationFeatureData as provided by, for example,
  pmsignature::readMPFile.\cr
  loadShiraishiSignatures():\tab loads Shiraishi signatures from flat files.\cr
  getSignatureListFromEstimatedParameters():\tab extracts a set of
  SIGNATURES from an EstimatedParameters object as computed by
  pmsignature::getPMSignature.\cr
  loadAlexandrovSignatures():\tab loads Alexandrov signatures in the
  COSMIC format from a flat file or URL.\cr
  convertAlexandrov2Shiraishi():\tab converts a set of Alexandrov
  signatures to Shiraishi signatures.\cr
  computeExplainedVariance():\tab determines the variance explained by
  estimated signature contributions/exposures.\cr
  plotExplainedVariance():\tab plots the variance of the genome's
  mutation load that can be explained with an increasing number of
  signatures.\cr
  plotDecomposedContribution():\tab plot a the decomposition/exposures
  of a genome to the mutational signatures.\cr
  plotMutationDistribution():\tab plot a single signature or mutation
  frequency data for a single genome.\cr
}
}
\author{
  Rosario M. Piro, Sandra Krueger\cr
  Freie Universitaet Berlin\cr
  Maintainer: Rosario M. Piro\cr
  E-Mail: <r.piro@fu-berlin.de> or <rmpiro@gmail.com>
}
\references{
  Krueger, Piro (2017) Identification of Mutational Signatures Active in
  Individual Tumors. NETTAB 2017 - Methods, Tools & Platforms for
  Personalized Medicine in the Big Data Era, October 16-18, 2017,
  Palermo, Italy. PeerJ Preprints 5:e3257v1, 2017.\cr
  http://rmpiro.net/index.html#downloads
}
\keyword{mutational signatures}
\keyword{mutation signatures}
\keyword{mutations}
\keyword{tumor genomes}
