\name{loadShiraishiSignatures}
\alias{loadShiraishiSignatures}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
  loadShiraishiSignatures
}
\description{
  Loads one or more Shiraishi signatures from flat files (one file per
  signature). The signatures must be specified as matrices
  without headers and row names.

  Format (see Shiraishi et al. PLoS Genetics 11(12):e1005657, 2015):

  First line:\cr
  Frequencies of the base changes C>A, C>G, C>T, T>A, T>C, and T>G

  Following 2k lines (for k up- and downstream flanking bases):\cr
  Frequencies of the bases A, C, G, and T, followed by two 0 values

  Final line (only if transcription direction is considered):\cr
  Frequencies of occurences on the transcription strand, and on the
  opposite strand, followed by four 0 values.

  Example:\cr
  1.8874e-14   0.10974   0.045918   0.11308   0.07429   0.65697\cr
  3.8079e-01   0.12215   0.191456   0.30561   0.00000   0.00000\cr
  1.5311e-01   0.34214   0.179774   0.32497   0.00000   0.00000\cr
  1.2378e-01   0.10243   0.163461   0.61032   0.00000   0.00000\cr
  3.4891e-01   0.15346   0.156687   0.34094   0.00000   0.00000\cr
  5.6435e-01   0.43565   0.000000   0.00000   0.00000   0.00000
}
\usage{
loadShiraishiSignatures(files)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{files}{
    (Mandatory) Can be a single file name, a vector of dile names, or a
    list of file names.
  }
}
%\details{
%}
\value{
  A list of Shiraishi signatures that can be used for decomposeTumorGenomes.
}
\references{
Krueger, Piro (2017) Identification of Mutational Signatures Active in
Individual Tumors. NETTAB 2017 - Methods, Tools & Platforms for
Personalized Medicine in the Big Data Era, October 16-18, 2017, Palermo,
Italy. PeerJ Preprints 5:e3257v1, 2017.\cr
http://rmpiro.net/index.html#downloads
}
\author{
  Rosario M. Piro, Sandra Krueger\cr
  Freie Universitaet Berlin\cr
  Maintainer: Rosario M. Piro\cr
  E-Mail: <r.piro@fu-berlin.de> or <rmpiro@gmail.com>
}
%\note{
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
  decompTumor2Sig\cr
  loadAlexandrovSignatures\cr
  getSignatureListFromEstimatedParameters\cr
}
%\examples{
%}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{mutational signatures}
\keyword{mutation signatures}
\keyword{mutations}
\keyword{tumor genomes}
